/*
 * $Id: ShutdownHookSequence.java 5981 2024-10-29 16:34:16Z carsten $
 *
 * Copyright 2012-2024 - Carsten Moeller Software
 * All rights reserved.
 * Use is subject to license terms.
 */

package de.cm.osm2po;

import java.util.Date;
import java.util.LinkedList;

import de.cm.osm2po.logging.Log;

/**
 * Erstellt einen ShutdownHook fuer eine definierte Reihenfolge.<br>
 * Ruft dafuer {@link Runtime#addShutdownHook(Thread)} und arbeitet
 * danach die mittels {@link #addFirst(ShutdownAware)} oder
 * {@link #addLast(ShutdownAware)} definierten Aufraeumarbeiten
 * sequentiell um. Wuerde jede Aktion einen eigenen Hook definieren,
 * so waere die Reihenfolge beliebig.
 * @author (c) 2024 - Carsten Moeller - info@osm2po
 */
public final class ShutdownHookSequence implements Runnable {
    private final LinkedList<ShutdownAware> shutdownList = new LinkedList<>();
    private Log log;

    public static interface ShutdownAware {
        void shutDown();
    }

    public ShutdownHookSequence(Log log) {
        this.log = log;
        Runtime.getRuntime().addShutdownHook(new Thread(this));
    }

    @Override
    public void run() {
        log.info("TERMSIG received. Starting Shutdown Sequence at " + new Date());
        for (ShutdownAware sa : this.shutdownList) {
            try {
                sa.shutDown();
            } catch (Throwable t) {
                log.fatal(t);
            }
        }
    }

    public void clear() {
        this.shutdownList.clear();
    }

    public void addFirst(ShutdownAware sa) {
        this.shutdownList.addFirst(sa);
    }

    public void addLast(ShutdownAware sa) {
        this.shutdownList.addLast(sa);
    }
}
