/*
 * $Id: LogJclWriter.java 5952 2024-10-21 11:41:05Z carsten $
 *
 * Copyright 2011 - Carsten Moeller Software
 * All rights reserved.
 * Use is subject to license terms.
 */

package de.cm.osm2po.logging;

import org.apache.commons.logging.LogFactory;

import de.cm.osm2po.Config;
import de.cm.osm2po.logging.Log.Level;

public class LogJclWriter implements LogWriter {

    private Level logLevel;
    private org.apache.commons.logging.Log jcl;

    public LogJclWriter() {
        this.logLevel = Level.NULL; // delegate all
    	this.jcl = LogFactory.getLog("osm2po");
    }

    /**
     * @return neue Log-Instanz mit einem {@link LogJclWriter}
     */
    public static Log logInstance() {
        return new Log(Level.NULL).addLogWriter(new LogJclWriter());
    }

    @Override
    public LogWriter open(Config config, int index) {
        if (config != null) {
            Log log = config.getLog();
            if (log != null) {
                log.debug("LogWriter[" + index + "] uses "
                        + this.jcl.getClass().getName());
            }
        }
        return this;
    }

    @Override
    public void log(String message, Level logLevel) {
        if (logLevel.severity < this.logLevel.severity) return;
        if (logLevel.severity < Level.FATAL.severity) // wegen Stacktrace
        	message = message.replace("\n", " ");
        try {
            // LEVEL_PROGRESS (4) ignored
	        switch (logLevel) {
	        case DATA: this.jcl.trace(message); break;
	        case BUGFIX: this.jcl.trace(message); break;
	        case DEBUG: this.jcl.debug(message); break;
	        case NOTE: this.jcl.debug(message); break;
	        case WARN: this.jcl.warn(message); break;
	        case INFO: this.jcl.info(message); break;
	        case ERROR: this.jcl.error(message); break;
	        case MESSAGE: this.jcl.info(message); break;
            case ALERT: this.jcl.error(message); break;
	        case FATAL: this.jcl.fatal(message); break;
	        default: // do nothing
	        }

        } catch (Exception e) {
        	throw new RuntimeException(e);
        }
    }

	@Override
	public LogWriter setLogLevel(Level logLevel) {
		this.logLevel = logLevel;
		return this;
	}

	@Override public Level getLogLevel() {return this.logLevel;}
    @Override public void close() {}

}
