/*
 * $Id: LogWriter.java 5952 2024-10-21 11:41:05Z carsten $
 *
 * Copyright 2011 - Carsten Moeller Software
 * All rights reserved.
 * Use is subject to license terms.
 */

package de.cm.osm2po.logging;

import de.cm.osm2po.Config;
import de.cm.osm2po.logging.Log.Level;

public interface LogWriter {

    /**
     * Initialisiert den Writer.
     * @param config {@link Config} NULLABLE.
     * @param index int optionaler index fuer Impl-Unterscheidung
     * @return muss this zurueckliefern.
     */
    LogWriter open(Config config, int index);

	/**
	 * Setzt das LogLevel.
	 * @param logLevel int z.B. {@link Level#DEBUG}
	 * @return this.
	 */
	LogWriter setLogLevel(Level logLevel);

	/**
	 * Liefert das LogLevel.
	 * @return int logLevel z.B.{@link Level#DEBUG}.
	 */
	Level getLogLevel();

    /**
     * Loggt.
     * @param message Message
     * @param logLevel Level, z.B. {@link Level#DEBUG}
     */
    void log(String message, Level logLevel);

    /**
     * Schliesst das Log. Sinnvoll bei z.B. Dateien.
     */
    void close();
}
