/*
 * $Id: SqlExecutor.java 5952 2024-10-21 11:41:05Z carsten $
 *
 * Copyright 2016 - Carsten Moeller Software
 * All rights reserved.
 * Use is subject to license terms.
 */

package de.cm.osm2po.postp;

import static de.cm.osm2po.Config.POSTP;

import java.sql.Connection;
import java.sql.Statement;

import de.cm.osm2po.Config;
import de.cm.osm2po.logging.Log;
import de.cm.osm2po.logging.Log.Level;
import de.cm.osm2po.misc.StatementExcecutor;

/**
 * Ein Postprozessor, der SQLs gegen eine DB feuert und
 * die Logs nach osm2po schreibt.
 * @author (c) 2016 - Carsten Moeller, info@osm2po.de
 */
public class SqlExecutor implements PostProcessor {

    /*  Standalone EXAMPLE:
        cmd=p
        db.connect=jdbc:postgresql://localhost:5432/worldgrid
        log.1.class=de.cm.osm2po.logging.LogConsoleWriter
        postp.2.class=de.cm.osm2po.postp.SqlExecutor
        "postp.2.sql=select cm_tile(''land_polygons_split'',20,-5,40,15); select cm_quad(2)"
    */

    @Override
    public void run(Config config, int index) throws Exception {
        Log log = config.getLog();
        String postp = POSTP(index);
        String dbConfPrefix = config.getProperty(postp + ".db");
        Connection dbCon = config.openDbConnection(dbConfPrefix);
        Statement stm = dbCon.createStatement();
        StatementExcecutor lsx =
            new StatementExcecutor(stm, log, Level.PROGRESS);

        // Multi-SQL-Mode
        for (int i = 0; i < 256; i++) {
            String sql = config.getProperty(postp + ".sql." + i);
            if (null == sql && 0 == i) { // .0-Index optional
                sql = config.getProperty(postp + ".sql");
            }
            if (sql != null) {
                if (!lsx.execute(sql))
                    log.error("Failed to execute " + sql);
            }
        }
        stm.close();
        dbCon.close();
    }
}
