/*
 * $Id: HttpLogFilter.java 5969 2024-10-26 20:29:40Z carsten $
 *
 * Copyright 2017 - Carsten Moeller Software
 * All rights reserved.
 * Use is subject to license terms.
 */

package de.cm.osm2po.service.filters;

import static de.cm.osm2po.misc.Utils.TS;

import java.util.List;
import java.util.Map.Entry;
import java.util.Set;

import com.sun.net.httpserver.HttpPrincipal;

import de.cm.osm2po.Config;
import de.cm.osm2po.logging.Log;
import de.cm.osm2po.logging.Log.Level;
import de.cm.osm2po.service.ServiceFilter;
import de.cm.osm2po.service.ServiceRequest;
import de.cm.osm2po.service.ServiceResponse;
import de.cm.osm2po.service.security.Principal2po;

/**
 * Ein {@link ServiceFilter}, der Requests auf
 * {@link Level#DEBUG} loggt.
 * @author (c) 2017 - Carsten Moeller - info@osm2po
 */
public class HttpLogFilter implements ServiceFilter {
    // TODO Config fuer mit und ohne HTTP-Header-Infos
    // TODO LogLevel konfigurierbar machen
    // TODO handle(...,target) Config Filter auf target

    private Log log;

    @Override
    public void init(Config config, int index) {
        this.log = config.getLog();
    }

    @Override public void shutDown() {}
    @Override public void postHandle(
            ServiceRequest req, ServiceResponse resp, boolean sent) {}

    @Override
    public boolean preHandle(ServiceRequest sr) throws Exception {
        StringBuilder sb = new StringBuilder(0x400);

        sb.append('[').append(sr.ip).append("] ").append(TS());
        sb.append('\n').append(sr.htx.getRequestMethod());
        sb.append(' ').append(sr.htx.getRequestURI());

        HttpPrincipal prince = sr.htx.getPrincipal();
        if (prince != null) {
            sb.append("\nPrincipal: " + prince.getUsername() + "@"+ prince.getRealm());
            if (prince instanceof Principal2po) {
                Set<String> roles = ((Principal2po)prince).roles;
                if (null == roles) {
                    sb.append(" [<NoRoles>]");
                } else {
                    sb.append(" " + roles.toString());
                }
            }
        }
        sb.append("\nHEADERS:");
        for (Entry<String, List<String>> headers : sr.htx.getRequestHeaders().entrySet()) {
            String hkey = headers.getKey();
            String hval = headers.getValue().toString(); // 0->N
            sb.append('\n').append(hkey).append("=").append(hval);
        }

        log.debug(sb.toString());

        return false;
    }

}
