/*
 * $Id: Principal2po.java 5883 2024-04-12 09:00:12Z carsten $
 *
 * Copyright 2024 - Carsten Moeller Software
 * All rights reserved.
 * Use is subject to license terms.
 */

package de.cm.osm2po.service.security;

import java.util.Objects;
import java.util.Set;

import com.sun.net.httpserver.HttpPrincipal;

import de.cm.osm2po.service.errors.ErrorEnum;

/**
 * Extends {@link HttpPrincipal} with some useful attributes.
 * @author (c) 2024 - Carsten Moeller - info@osm2po
 */
public class Principal2po extends HttpPrincipal {
    public final Set<String> roles;
    public final ErrorEnum error;

    /**
     * Creates a valid Principal.
     * @param username String NOT NULL
     * @param realm String NOT NULL
     * @param roles Set of Roles NULLABLE
     */
    public Principal2po(String username, String realm, Set<String> roles) {
        super(username, realm);
        this.roles = roles;
        this.error = null;
    }

    /**
     * Creates an anonymous Principal with Error.
     * @param error {@link ErrorEnum} NOT NULL
     * @param realm String NOT NULL
     */
    public Principal2po(ErrorEnum error, String realm) {
        super("", realm);
        Objects.requireNonNull(error);
        this.roles = null;
        this.error = error;
    }

    public final boolean hasError() {
        return this.error != null;
    }
}
